@@ -34,7 +34,7 @@ from sure.registry import context as _registry
 from sure.magic import is_cpython, patchable_builtin
 from sure.terminal import red, green, white, yellow
 
-version = '1.0.4'
+version = '1.0.5'
 
 
 def _get_file_name(func):
@@ -961,6 +961,7 @@ class AssertionBuilder(object):
             obj = obj.obj
 
         self.obj = obj
+        self.repr = repr(obj)
         self._that = that(obj)
 
         return self
@@ -984,6 +985,17 @@ class AssertionBuilder(object):
 
         return super(AssertionBuilder, self).__getattribute__(attr)
 
+    @assertionproperty
+    def callable(self):
+        if self.negative:
+            assert not callable(self.obj), (
+                'expected `{0}` to not be callable but it is'.format(repr(self.obj)))
+        else:
+            assert callable(self.obj), (
+                'expected {0} to be callable'.format(repr(self.obj)))
+
+        return True
+
     @assertionproperty
     def be(self):
         return self
@@ -998,10 +1010,15 @@ class AssertionBuilder(object):
 
     @assertionproperty
     def empty(self):
+        length = len(self.obj)
         if self.negative:
-            return self._that.len_greater_than(0)
+            assert length > 0, (
+                u"expected `{0}` to not be empty".format(repr(self.obj)))
         else:
-            return self._that.len_is(0)
+            assert length is 0, (
+                u"expected `{0}` to be empty but it has {1} items".format(self.repr, length))
+
+        return True
 
     @assertionproperty
     def ok(self):
@@ -1042,13 +1059,11 @@ class AssertionBuilder(object):
         return True
 
     @assertionmethod
-    def within(self, *args):
-        assert args, u'you should provide at least one argument to .within()'
-
-        first = args[0]
+    def within(self, first, *rest):
         if isinstance(first, Iterable):
             collection_should = that(first)
         else:
+            args = [first] + list(rest)
             collection_should = that(range(*args))
 
         if self.negative:
@@ -1068,16 +1083,40 @@ class AssertionBuilder(object):
 
     @assertionmethod
     def an(self, klass):
+        if isinstance(klass, type):
+            class_name = klass.__name__
+        elif isinstance(klass, basestring):
+            class_name = klass.strip()
+        else:
+            class_name = unicode(klass)
+
+        is_vowel = class_name[0] in 'aeiou'
+
         if isinstance(klass, basestring):
             if '.' in klass:
                 items = klass.split('.')
                 first = items.pop(0)
+                if not items:
+                    items = [first]
+                    first = '_abcoll'
             else:
                 first = u'__builtin__'
                 items = [klass]
 
             klass = reduce(getattr, items, __import__(first))
-        return self._that.is_a(klass)
+
+        suffix = is_vowel and "n" or ""
+
+        if self.negative:
+            assert not isinstance(self.obj, klass), (
+                'expected `{0}` to not be a{1} {2}'.format(
+                    self.obj, suffix, class_name))
+
+        else:
+            assert isinstance(self.obj, klass), (
+                'expected `{0}` to be a{1} {2}'.format(
+                    self.obj, suffix, class_name))
+        return True
 
     a = an
 
